@@ -18,6 +18,7 @@
  */
 
 #include "screenshooter-capture.h"
+#include "screenshooter-utils.h"
 
 #define BACKGROUND_TRANSPARENCY 0.4
 
@@ -61,11 +62,6 @@ typedef struct
 
 /* Prototypes */
 
-
-
-static GdkWindow       *get_active_window                   (GdkScreen      *screen,
-                                                             gboolean       *needs_unref,
-                                                             gboolean       *border);
 static void             free_pixmap_data                    (guchar *pixels,
                                                              gpointer data);
 static GdkPixbuf       *get_cursor_pixbuf                   (GdkDisplay *display,
@@ -107,64 +103,6 @@ static GdkPixbuf       *get_rectangle_screenshot_composited (gint delay);
 
 
 
-static GdkWindow
-*get_active_window (GdkScreen *screen,
-                    gboolean  *needs_unref,
-                    gboolean  *border)
-{
-  GdkWindow *window, *window2;
-
-  TRACE ("Get the active window");
-
-  window = gdk_screen_get_active_window (screen);
-
-  /* If there is no active window, we fallback to the whole screen. */
-  if (G_UNLIKELY (window == NULL))
-    {
-      TRACE ("No active window, fallback to the root window");
-
-      window = gdk_get_default_root_window ();
-      *needs_unref = FALSE;
-      *border = FALSE;
-    }
-  else if (G_UNLIKELY (gdk_window_is_destroyed (window)))
-    {
-      TRACE ("The active window is destroyed, fallback to the root window.");
-
-      g_object_unref (window);
-      window = gdk_get_default_root_window ();
-      *needs_unref = FALSE;
-      *border = FALSE;
-    }
-  else if (gdk_window_get_type_hint (window) == GDK_WINDOW_TYPE_HINT_DESKTOP)
-    {
-      /* If the active window is the desktop, grab the whole screen */
-      TRACE ("The active window is the desktop, fallback to the root window");
-
-      g_object_unref (window);
-
-      window = gdk_get_default_root_window ();
-      *needs_unref = FALSE;
-      *border = FALSE;
-    }
-  else
-    {
-      /* Else we find the toplevel window to grab the decorations. */
-      TRACE ("Active window is a normal window, grab the toplevel window");
-
-      window2 = gdk_window_get_toplevel (window);
-
-      g_object_unref (window);
-
-      window = window2;
-      *border = TRUE;
-    }
-
-  return window;
-}
-
-
-
 static Window
 find_wm_window (Window xid)
 {
@@ -306,6 +244,7 @@ static GdkPixbuf
 
   gint scale;
   GdkRectangle rectangle;
+  GdkRectangle screen_geometry;
 
   /* Get the root window */
   TRACE ("Get the root window");
@@ -314,9 +253,9 @@ static GdkPixbuf
 
   if (border)
     {
-	  Window xwindow = GDK_WINDOW_XID (window);
+      Window xwindow = GDK_WINDOW_XID (window);
       window = gdk_x11_window_foreign_new_for_display (gdk_window_get_display (window),
-    		                                           find_wm_window (xwindow));
+                                                      find_wm_window (xwindow));
     }
 
   scale = gdk_window_get_scale_factor (window);
@@ -334,6 +273,8 @@ static GdkPixbuf
   width  = rectangle.width;
   height = rectangle.height;
 
+  screenshooter_get_screen_geometry (&screen_geometry);
+
   if (x_orig < 0)
     {
       width = width + x_orig;
@@ -346,11 +287,11 @@ static GdkPixbuf
       y_orig = 0;
     }
 
-  if (x_orig + width > gdk_screen_width ())
-    width = gdk_screen_width () - x_orig;
+  if (x_orig + width > screen_geometry.width)
+    width = screen_geometry.width - x_orig;
 
-  if (y_orig + height > gdk_screen_height ())
-    height = gdk_screen_height () - y_orig;
+  if (y_orig + height > screen_geometry.height)
+    height = screen_geometry.height - y_orig;
 
   /* Capture the screenshot from the root GdkWindow, to grab things such as
    * menus. */
@@ -421,11 +362,11 @@ static GdkPixbuf
                   rec_y = 0;
                 }
 
-              if (x_orig + rec_x + rec_width > gdk_screen_width () * scale)
-                rec_width = gdk_screen_width () * scale - x_orig - rec_x;
+              if (x_orig + rec_x + rec_width > screen_geometry.width * scale)
+                rec_width = screen_geometry.width * scale - x_orig - rec_x;
 
-              if (y_orig + rec_y + rec_height > gdk_screen_height () * scale)
-                rec_height = gdk_screen_height () * scale - y_orig - rec_y;
+              if (y_orig + rec_y + rec_height > screen_geometry.height * scale)
+                rec_height = screen_geometry.height * scale - y_orig - rec_y;
 
               for (y = rec_y; y < rec_y + rec_height; y++)
                 {
@@ -927,6 +868,7 @@ static GdkPixbuf
   GdkSeat   *seat;
   GdkCursor *xhair_cursor;
   GdkDisplay *display;
+  GdkRectangle screen_geometry;
 
   /* Initialize the rubber band data */
   rbdata.left_pressed = FALSE;
@@ -970,10 +912,12 @@ static GdkPixbuf
   display = gdk_display_get_default ();
   gtk_widget_realize (window);
   xhair_cursor = gdk_cursor_new_for_display (display, GDK_CROSSHAIR);
+
+  screenshooter_get_screen_geometry (&screen_geometry);
+
   gdk_window_set_override_redirect (gtk_widget_get_window (window), TRUE);
   gtk_widget_set_size_request (window,
-                               gdk_screen_get_width (gdk_screen_get_default ()),
-                               gdk_screen_get_height (gdk_screen_get_default ()));
+                               screen_geometry.width, screen_geometry.height);
   gdk_window_raise (gtk_widget_get_window (window));
   gtk_widget_show_now (window);
   gtk_widget_grab_focus (window);
@@ -1423,7 +1367,9 @@ GdkPixbuf *screenshooter_capture_screenshot (gint     region,
   display = gdk_display_get_default ();
   gdk_display_sync (display);
 
+G_GNUC_BEGIN_IGNORE_DEPRECATIONS
   gdk_window_process_all_updates ();
+G_GNUC_END_IGNORE_DEPRECATIONS
 
   /* Get the window/desktop we want to screenshot*/
   if (region == FULLSCREEN)
@@ -1438,7 +1384,7 @@ GdkPixbuf *screenshooter_capture_screenshot (gint     region,
     {
       TRACE ("We grab the active window");
 
-      window = get_active_window (screen, &needs_unref, &border);
+      window = screenshooter_get_active_window (screen, &needs_unref, &border);
     }
 
   if (region == FULLSCREEN || region == ACTIVE_WINDOW)
