@@ -17,10 +17,70 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
 
+#include <X11/Xlib.h>
+#include <X11/Xatom.h>
+#include <gdk/gdk.h>
+#include <gdk/gdkx.h>
+
 #include "screenshooter-utils.h"
 #include <libxfce4ui/libxfce4ui.h>
 
 
+
+/* Internals */
+
+
+
+/* Replacement for gdk_screen_get_active_window */
+static Window
+get_active_window_from_xlib (void)
+{
+  GdkDisplay *display;
+  Display *dsp;
+  Atom active_win, type;
+  int status, format;
+  unsigned long n_items, bytes_after;
+  unsigned char *prop;
+  Window window;
+
+  display = gdk_display_get_default ();
+  dsp = gdk_x11_display_get_xdisplay (display);
+
+  active_win = XInternAtom (dsp, "_NET_ACTIVE_WINDOW", True);
+  if (active_win == None)
+    return None;
+
+  gdk_x11_display_error_trap_push (display);
+
+  status = XGetWindowProperty (dsp, DefaultRootWindow (dsp),
+                               active_win, 0, G_MAXLONG, False,
+                               XA_WINDOW, &type, &format, &n_items,
+                               &bytes_after, &prop);
+
+  if (status != Success || type != XA_WINDOW)
+    {
+      if (prop)
+        XFree (prop);
+
+      gdk_x11_display_error_trap_pop_ignored (display);
+      return None;
+    }
+
+  if (gdk_x11_display_error_trap_pop (display) != Success)
+    {
+      if (prop)
+        XFree (prop);
+
+      return None;
+    }
+
+  window = *(Window *) prop;
+  XFree (prop);
+  return window;
+}
+
+
+
 /* Public */
 
 
@@ -258,21 +318,6 @@ gboolean screenshooter_is_remote_uri (const gchar *uri)
 
 
 
-gchar *rot13 (gchar *string)
-{
-  gchar *result = string;
-
-  for (; *string; string++)
-    if (*string >= 'a' && *string <= 'z')
-      *string = (*string - 'a' + 13) % 26 + 'a';
-    else if (*string >= 'A' && *string <= 'Z')
-      *string = (*string - 'A' + 13) % 26 + 'A';
-
-  return result;
-}
-
-
-
 /**
  * screenshooter_error:
  * @format: printf()-style format string
@@ -346,3 +391,98 @@ screenshooter_f1_key (GtkWidget *widget, GdkEventKey *event, gpointer user_data)
 
   return FALSE;
 }
+
+
+
+/* Replacement for gdk_screen_width/gdk_screen_height */
+void
+screenshooter_get_screen_geometry (GdkRectangle *geometry)
+{
+  GdkDisplay *display = gdk_display_get_default ();
+  int num_monitors = gdk_display_get_n_monitors (display);
+
+  gint x, y, w, h;
+
+  x = y = G_MAXINT;
+  w = h = G_MININT;
+
+  for (int i = 0; i < num_monitors; i++)
+    {
+      GdkRectangle rect;
+      GdkMonitor *monitor = gdk_display_get_monitor (display, i);
+      gdk_monitor_get_geometry (monitor, &rect);
+
+      x = MIN (x, rect.x);
+      y = MIN (y, rect.y);
+      w = MAX (w, rect.x + rect.width);
+      h = MAX (h, rect.y + rect.height);
+    }
+
+  geometry->width = w - x;
+  geometry->height = h - y;
+}
+
+
+
+GdkWindow*
+screenshooter_get_active_window (GdkScreen *screen,
+                                 gboolean  *needs_unref,
+                                 gboolean  *border)
+{
+  GdkWindow *window, *window2;
+  Window xwindow;
+  GdkDisplay *display;
+
+  TRACE ("Get the active window");
+
+  display = gdk_display_get_default ();
+  xwindow = get_active_window_from_xlib ();
+  if (xwindow != None)
+    window = gdk_x11_window_foreign_new_for_display (display, xwindow);
+  else
+    window = NULL;
+
+  /* If there is no active window, we fallback to the whole screen. */
+  if (G_UNLIKELY (window == NULL))
+    {
+      TRACE ("No active window, fallback to the root window");
+
+      window = gdk_get_default_root_window ();
+      *needs_unref = FALSE;
+      *border = FALSE;
+    }
+  else if (G_UNLIKELY (gdk_window_is_destroyed (window)))
+    {
+      TRACE ("The active window is destroyed, fallback to the root window.");
+
+      g_object_unref (window);
+      window = gdk_get_default_root_window ();
+      *needs_unref = FALSE;
+      *border = FALSE;
+    }
+  else if (gdk_window_get_type_hint (window) == GDK_WINDOW_TYPE_HINT_DESKTOP)
+    {
+      /* If the active window is the desktop, grab the whole screen */
+      TRACE ("The active window is the desktop, fallback to the root window");
+
+      g_object_unref (window);
+
+      window = gdk_get_default_root_window ();
+      *needs_unref = FALSE;
+      *border = FALSE;
+    }
+  else
+    {
+      /* Else we find the toplevel window to grab the decorations. */
+      TRACE ("Active window is a normal window, grab the toplevel window");
+
+      window2 = gdk_window_get_toplevel (window);
+
+      g_object_unref (window);
+
+      window = window2;
+      *border = TRUE;
+    }
+
+  return window;
+}
