@@ -78,7 +78,7 @@ static GOptionEntry entries[] =
   },
   {
     "save", 's', G_OPTION_FLAG_IN_MAIN, G_OPTION_ARG_FILENAME, &screenshot_dir,
-    N_("Directory where the screenshot will be saved"),
+    N_("File path or directory where the screenshot will be saved"),
     NULL
   },
   {
@@ -105,34 +105,6 @@ static GOptionEntry entries[] =
 
 
 
-static void
-take_screenshot (ScreenshotData *sd, gboolean from_cli)
-{
-  if (sd->region == SELECT)
-    {
-      /* The delay will be applied after the rectangle selection */
-      g_idle_add ((GSourceFunc) screenshooter_take_screenshot_idle, sd);
-      return;
-    }
-
-  if (sd->delay == 0 && from_cli)
-    {
-      /* If delay is zero and the region was passed as an argument, thus the
-       * first dialog was not shown, we will take the screenshot immediately
-       * without a minimal delay */
-      g_idle_add ((GSourceFunc) screenshooter_take_screenshot_idle, sd);
-      return;
-    }
-
-  /* Await the amount of the time specified by the user before capturing the
-   * screenshot, but not less than 200ms, otherwise the first dialog might
-   * appear on the screenshot. */
-  gint delay = sd->delay == 0 ? 200 : sd->delay * 1000;
-  g_timeout_add (delay, (GSourceFunc) screenshooter_take_screenshot_idle, sd);
-}
-
-
-
 static void
 cb_dialog_response (GtkWidget *dialog, gint response, ScreenshotData *sd)
 {
@@ -144,7 +116,7 @@ cb_dialog_response (GtkWidget *dialog, gint response, ScreenshotData *sd)
   else if (response == GTK_RESPONSE_OK)
     {
       gtk_widget_destroy (dialog);
-      take_screenshot (sd, FALSE);
+      screenshooter_take_screenshot (sd, FALSE);
     }
   else
     {
@@ -172,6 +144,7 @@ int main (int argc, char **argv)
 
   ScreenshotData *sd = g_new0 (ScreenshotData, 1);
   sd->plugin = FALSE;
+  sd->path_is_dir = TRUE;
   sd->app_info = NULL;
   sd->action = 0;
 
@@ -283,12 +256,16 @@ int main (int argc, char **argv)
   if (fullscreen || window || region)
     {
       /* Set the region to be captured */
+      sd->region_specified = TRUE;
+
       if (window)
         sd->region = ACTIVE_WINDOW;
       else if (fullscreen)
         sd->region = FULLSCREEN;
       else if (region)
         sd->region = SELECT;
+      else
+        sd->region_specified = FALSE;
 
       /* Whether to display the mouse pointer on the screenshot */
       mouse ? (sd->show_mouse = 1) : (sd->show_mouse = 0);
@@ -330,22 +307,18 @@ int main (int argc, char **argv)
         {
           default_save_dir = g_file_new_for_commandline_arg (screenshot_dir);
 
-          if (G_LIKELY (g_file_query_exists (default_save_dir, NULL)))
-            {
-              g_free (sd->screenshot_dir);
-              sd->screenshot_dir = g_file_get_uri (default_save_dir);
-              sd->action_specified = TRUE;
-            }
-          else
-              screenshooter_error (_("%s is not a valid directory, the default"
-                                   " directory will be used."),
-                                   screenshot_dir);
+          sd->action_specified = TRUE;
+          g_free (sd->screenshot_dir);
+          sd->screenshot_dir = g_file_get_uri (default_save_dir);
+
+          // Check if given path is a directory
+          sd->path_is_dir = g_file_test (screenshot_dir, G_FILE_TEST_IS_DIR);
 
           g_object_unref (default_save_dir);
           g_free (screenshot_dir);
         }
 
-      take_screenshot (sd, TRUE);
+      screenshooter_take_screenshot (sd, TRUE);
     }
   /* Else we show a dialog which allows to set the screenshot options */
   else
